@@ -204,15 +204,6 @@ class YAFFSEntry:
     st_mtime: int = attrs.field(default=0)
     st_ctime: int = attrs.field(default=0)
 
-    def __lt__(self, other):
-        return self.object_id < other.object_id
-
-    def __gt__(self, other):
-        return self.object_id > other.object_id
-
-    def __eq__(self, other):
-        return self.object_id == other.object_id
-
     def __str__(self):
         return f"{self.object_id}: {self.name}"
 
